from __future__ import division
from pylab import *

# Program to read outputs of case stude 1 using the MESA stellar evolution code
# Comment / uncomment plots according to what you want to visualize

# Reading history.data MESA output file

history=loadtxt('history.data',skiprows=7)
model_number = history[:,0]
star_age = history[:,1]
star_mass = history[:,2]
log_Teff = history[:,3]
log_L = history[:,4]
log_R = history[:,5]
log_center_T = history[:,6]
log_center_Rho = history[:,7]
log_center_P = history[:,8]
core_deg = history[:,9]
log_Lnuc = history[:,10]
log_abs_Lgrav = history[:,11]
center_h1 = history[:,13]
center_he3 = history[:,14]
center_he4 = history[:,15]
center_c12 = history[:,16]
center_n14 = history[:,17]
surf_h1 = history[:,18]
surf_he3 = history[:,19]
surf_he4 = history[:,20]
surf_c12 = history[:,21]
surf_n14 = history[:,22]
pp = history[:,23]
cno = history[:,24]
trialpha = history[:,25]


# Luminosities plot
Lnuc,Lgrav=semilogx(star_age,log_Lnuc,star_age,log_abs_Lgrav)
xlabel('log age (years)')
ylabel('Lnuc,Lgrav')
legend((Lnuc,Lgrav),('Lnuc','Lgrav'), 'lower right')
title('Gravitaitonal versus nuclear luminosities')
show()

# Core Abundances plot

H,He3,He4,C12,N14=semilogx(star_age,center_h1,star_age,center_he3,star_age,center_he4,star_age,center_c12,star_age,center_n14)
xlim(1,1.1e10)
ylim(-8,0)
xlabel('log age (years)')
ylabel('Log10 of central mass fractions')
legend((H,He3,He4,C12,N14),('H','He3','He4','C12','N14'), 'lower right')
title('Evolution of central mass fractions')
show()

# Surface abundances
H,He3,He4,C12,N14=semilogx(star_age,surf_h1,star_age,surf_he3,star_age,surf_he4,star_age,surf_c12,star_age,surf_n14)
xlim(1,1.1e10)
ylim(-8,0)
xlabel('log age (years)')
ylabel('Log10 of surface mass fractions')
legend((H,He3,He4,C12,N14),('H','He3','He4','C12','N14'), 'lower right')
title('Evolution of surface mass fractions')
show()


# Nuclear energy plot
pp,cno,trialpha=semilogx(star_age,pp,star_age,cno,star_age,trialpha)
xlim(1,1.1e10)
ylim(-40,0.5)
xlabel('log age (years)')
ylabel('Energy from pp chains and CNO cycle')
legend((pp,cno,trialpha),('pp','CNO','triple alpha'), 'lower right')
title('Evolution of the energy generation for H burning via pp chains or CNO cycle')
show()


# Reading MESA profiles output files
prof=open('profiles.index','r')
l=prof.readline()
models=l.split()
mod=models[0]
prof.close()



for i in range(1,int(mod)+1):
    print 'profile' + str(i) + '.data'
    profile=loadtxt('profile' + str(i) + '.data',skiprows=6)
    n=profile[:,0]
    q=profile[:,1]
    logR=profile[:,2]
    logT=profile[:,3]
    logrho=profile[:,4]
    logP=profile[:,5]
    logh=profile[:,6]
    loghe3=profile[:,7]
    loghe4=profile[:,8]
    logc12=profile[:,9]
    logn14=profile[:,10]
    logkap=profile[:,11]
    logtau=profile[:,12]

    # Evolution of the internal profiles

    H,He3,He,C12,N14=semilogy(logR,logh,logR,loghe3,logR,loghe4,logR,logc12,logR,logn14)
    xlim(-3,1.5)
    xlabel('log r/R')
    ylabel('log Mass fraction')
    legend((H,He3,He,C12,N14),('H','He3','He','C12','N14'),'lower left')
    show()

